"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const fs = require("fs-extra");
const request = require("request-promise-native");
const rimraf = require("rimraf");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('sfpowerkit', 'sandbox_create');
class Create extends command_1.SfdxCommand {
    async run() {
        rimraf.sync('temp_sfpowerkit');
        const conn = this.org.getConnection();
        this.flags.apiversion = this.flags.apiversion || await conn.retrieveMaxApiVersion();
        const uri = `${conn.instanceUrl}/services/data/v${this.flags.apiversion}/tooling/sobjects/SandboxInfo/`;
        this.ux.log(`${this.flags.apexclass}  ${this.flags.clonefrom} `);
        const result = await request({
            method: 'post',
            uri,
            headers: {
                Authorization: `Bearer ${conn.accessToken}`
            },
            body: {
                AutoActivate: 'true',
                SandboxName: `${this.flags.name}`,
                Description: `${this.flags.description}`,
                LicenseType: `${this.flags.licensetype}`,
                ApexClassId: `${this.flags.apexclass}`,
                SourceId: `${this.flags.clonefrom}`
            },
            json: true
        });
        this.ux.log(result);
        if (this.flags.outputfile) {
            await fs.outputJSON(this.flags.outputfile, result);
        }
        rimraf.sync('temp_sfpowerkit');
        return result;
    }
}
Create.description = messages.getMessage('commandDescription');
Create.examples = [
    `$ sfdx sfpowerkit:org:sandbox:create -d Testsandbox -l DEVELOPER -n test2 -u myOrg@example.com
  Successfully Enqueued Creation of Sandbox
  `
];
Create.flagsConfig = {
    name: command_1.flags.string({ required: true, char: 'n', description: messages.getMessage('nameFlagDescription') }),
    description: command_1.flags.string({ required: true, char: 'd', description: messages.getMessage('descriptionFlagDescription') }),
    licensetype: command_1.flags.string({ required: true, char: 'l', options: ['DEVELOPER', 'DEVELOPER_PRO', 'PARTIAL', 'FULL'], description: messages.getMessage('licenseFlagDescription') }),
    apexclass: command_1.flags.string({ required: false, char: 'a', default: '', description: messages.getMessage('apexClassFlagDescription') }),
    clonefrom: command_1.flags.string({ required: false, char: 'f', default: '', description: messages.getMessage('cloneFromFlagDescripton') })
};
// Comment this out if your command does not require an org username
Create.requiresUsername = true;
exports.default = Create;
//# sourceMappingURL=create.js.map